lookup_impl_method_query

Function lookup_impl_method_query 

pub(crate) fn lookup_impl_method_query<'db>(
    db: &'db dyn HirDatabase,
    env: ParamEnvAndCrate<'db>,
    func: FunctionId,
    fn_subst: GenericArgs<'db>,
) -> (Either<FunctionId, (BuiltinDeriveImplId, BuiltinDeriveImplMethod)>, GenericArgs<'db>)
Looks up the impl method that actually runs for the trait method func.

Returns func if it’s not a method defined in a trait or the lookup failed.