pub(crate) enum TreatNotYetDefinedOpaques {
AsInfer,
AsRigid,
}Expand description
Used by FnCtxt::lookup_method_for_operator with -Znext-solver.
With AsRigid we error on impl Opaque: NotInItemBounds while
AsInfer just treats it as ambiguous and succeeds. This is necessary
as we want FnCtxt::check_expr_call to treat not-yet-defined opaque
types as rigid to support impl Deref<Target = impl FnOnce()> and
Box<impl FnOnce()>.
We only want to treat opaque types as rigid if we need to eagerly choose between multiple candidates. We otherwise treat them as ordinary inference variable to avoid rejecting otherwise correct code.
Variants